@@ -1,7 +1,7 @@
-#' Optimise registration parameters with Simulated Annealing
+#' Optimise registration parameters
 #'
 #' @param data Input data frame containing all replicates of gene expression for a single genotype at each time point.
-#' @param overlapping_percent Number of minimum overlapping time points. Shifts will be only considered if it leaves at least these many overlapping points after applying the registration function.
+#' @param overlapping_percent Minimum normalised percentage of overlapping time points on the reference data. Shifts will be only considered if it leaves at least this percentage of overlapping time points after applying the registration function.
 #' @param optimisation_config List with arguments to modify the optimisation configuration.
 #' @param optimise_fun Optimisation function to use. Can be \code{optimise_using_nm} or \code{optimise_using_nm}.
 #'
@@ -12,12 +12,9 @@ optimise <- function(data,
                      overlapping_percent = 0.5,
                      optimisation_config,
                      optimise_fun) {
-  # Calculate boundary box and initial guess
-  if (all(is.na(stretches), is.na(shifts))) {
-    space_lims <- get_search_space_limits(data, overlapping_percent)
-  } else {
-    space_lims <- get_search_space_limits_from_params(stretches, shifts)
-  }
+
+  # Calculate boundary box
+  space_lims <- get_search_space_limits(data, stretches, shifts, overlapping_percent)
 
   # Run optimisation
   optimised_params <- optimise_fun(
@@ -30,7 +27,7 @@ optimise <- function(data,
   return(optimised_params)
 }
 
-#' Objective loss function for Simulated Annealing
+#' Objective loss function
 #'
 #' @noRd
 objective_fun <- function(data, stretch, shift, overlapping_percent, maximize = TRUE) {
@@ -56,111 +53,6 @@ objective_fun <- function(data, stretch, shift, overlapping_percent, maximize =
   )
 }
 
-#' Calculate limits of the search space for Simulated Annealing
-#'
-#' @noRd
-get_search_space_limits <- function(data, overlapping_percent = 0.5) {
-  # Suppress "no visible binding for global variable" note
-  accession <- NULL
-  timepoint <- NULL
-
-  # Initial stretch limits
-  stretch_init <- get_approximate_stretch(data)
-  stretch_lower <- 0.5 * stretch_init
-  stretch_upper <- 1.5 * stretch_init
-
-  # Extract time point ranges
-  timepoints_ref <- unique(data[accession == "ref", timepoint])
-  timepoints_query <- unique(data[accession == "query", timepoint])
-
-  # Calculate time point ranges
-  range_ref <- diff(range(timepoints_ref))
-  range_query <- diff(range(timepoints_query))
-  range_query_max_stretch <- stretch_upper * range_query
-
-  # Calculate minimum and maximum timepoints in which the curves overlap
-  min_timepoint <- min(timepoints_ref) + overlapping_percent * range_ref - range_query_max_stretch
-  max_timepoint <- max(timepoints_ref) - overlapping_percent * range_ref + range_query_max_stretch
-
-  # Calculate shift limits
-  shift_lower <- min_timepoint - min(timepoints_query)
-  shift_upper <- (max_timepoint - range_query_max_stretch) - min(timepoints_query)
-
-  # Calculate initial shift value (zero if possible)
-  shift_init <- 0
-  if (shift_init < shift_lower | shift_init > shift_upper) {
-    shift_init <- mean(c(shift_lower, shift_upper))
-  }
-
-  # Results object
-  results_list <- list(
-    stretch_init = stretch_init,
-    stretch_lower = stretch_lower,
-    stretch_upper = stretch_upper,
-    shift_init = shift_init,
-    shift_lower = shift_lower,
-    shift_upper = shift_upper
-  )
-
-  return(results_list)
-}
-
-#' Calculate limits of the search space for Simulated Annealing from provided registration parameters
-#'
-#' @noRd
-get_search_space_limits_from_params <- function(stretches, shifts) {
-  # Initial stretch limits
-  stretch_lower <- min(stretches)
-  stretch_upper <- max(stretches)
-  stretch_init <- mean(stretches)
-
-  # Calculate shift limits
-  shift_lower <- min(shifts)
-  shift_upper <- max(shifts)
-
-  # Calculate initial shift value (zero if possible)
-  shift_init <- 0
-  if (shift_init < shift_lower | shift_init > shift_upper) {
-    shift_init <- mean(c(shift_lower, shift_upper))
-  }
-
-  # Results object
-  results_list <- list(
-    stretch_init = stretch_init,
-    stretch_lower = stretch_lower,
-    stretch_upper = stretch_upper,
-    shift_init = shift_init,
-    shift_lower = shift_lower,
-    shift_upper = shift_upper
-  )
-
-  return(results_list)
-}
-
-#' Calculate overlapping percentage between reference and query data time point ranges
-#'
-#' @noRd
-calc_overlapping_percent <- function(data) {
-  # Suppress "no visible binding for global variable" note
-  accession <- NULL
-  timepoint <- NULL
-
-  # Extract time point ranges
-  range_ref <- range(unique(data[accession == "ref", timepoint]))
-  range_query <- range(unique(data[accession == "query", timepoint]))
-
-  if (all(range_ref[2] >= range_query[2], range_ref[1] <= range_query[1])) {
-    # Query is fully contained on reference
-    overlapping_percent <- 1
-  } else {
-    # Calculate overlapping percent over reference
-    overlap <- min(c(range_ref[2], range_query[2])) - max(c(range_ref[1], range_query[1]))
-    overlapping_percent <- overlap / diff(range_ref)
-  }
-
-  return(overlapping_percent)
-}
-
 #' Optimise stretch and shift using Simulated Annealing
 #'
 #' @noRd
@@ -230,7 +122,7 @@ optimise_using_nm <- function(data,
   shift_lower <- space_lims$shift_lower
   shift_upper <- space_lims$shift_upper
 
-  # Define data as it object required by optim::sa()
+  # Define data structure required by {neldermead}
   fmsfundata <- structure(
     list(data = data),
     class = "optimbase.functionargs"
@@ -303,7 +195,6 @@ optimise_using_lbfgsb <- function(data,
                                   optimisation_config = NULL,
                                   overlapping_percent,
                                   space_lims) {
-
   # Parse initial and limit parameters
   stretch_init <- space_lims$stretch_init
   shift_init <- space_lims$shift_init
@@ -346,5 +237,3 @@ optimise_using_lbfgsb <- function(data,
 
   return(params_list)
 }
-
-
