@@ -4,8 +4,7 @@ query <- "Col0"
 gene_data <- brapa_sample_data[gene_id == "BRAA03G051930.3C"]
 
 test_that("calc_loglik_H1 and calc_loglik_H2 work", {
-  processed_data <- preprocess_data(gene_data, reference, query)
-  all_data <- processed_data$all_data
+  all_data <- preprocess_data(gene_data, reference, query, scaling_method = "z-score")
 
   # Expected outputs
   expect_no_error(calc_loglik_H2(all_data))
